@@ -3,7 +3,7 @@
 """
 Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-SPDX-License-Identifier: GPL-2.0
+SPDX-License-Identifier: GPL-2.0-only
 
 """
 
@@ -100,7 +100,7 @@ class ChatView(MJTableView):
     """define a minimum size"""
 
     def __init__(self) ->None:
-        MJTableView.__init__(self)
+        super().__init__()
 
     def sizeHint(self) ->QSize:
         """sizeHint"""
@@ -133,9 +133,8 @@ class ChatWindow(QWidget):
         self.messageView.setWordWrap(False)
         self.messageView.setSelectionMode(QAbstractItemView.SelectionMode.NoSelection)
         if Debug.modelTest:
-            self.debugModelTest = ModelTest(
-                self.messageView.model(),
-                self.messageView)
+            if model := self.messageView.model():
+                self.debugModelTest = ModelTest(model, self.messageView)
         self.edit = QLineEdit()
         layout = QVBoxLayout()
         layout.addWidget(self.messageView)
@@ -151,7 +150,7 @@ class ChatWindow(QWidget):
         self.activateWindow()
         self.setWindowState(cast(Qt.WindowState, self.windowState() & ~Qt.WindowState.WindowMinimized))
         self.raise_()
-        QWidget.show(self)
+        super().show()
 
     def isVisible(self) ->bool:
         """not only visible but also not minimized"""
@@ -195,10 +194,11 @@ class ChatWindow(QWidget):
     def receiveLine(self, chatLine:ChatMessage) ->None:
         """show a new line in protocol"""
         self.show()
-        cast(ChatModel, self.messageView.model()).appendLine(chatLine)
-        for row in range(self.messageView.model().rowCount()):
-            self.messageView.setRowHeight(
-                row,
-                self.messageView.fontMetrics().height())
+        if model := self.messageView.model():
+            cast(ChatModel, model).appendLine(chatLine)
+            for row in range(model.rowCount()):
+                self.messageView.setRowHeight(
+                    row,
+                    self.messageView.fontMetrics().height())
         self.messageView.resizeColumnsToContents()
         self.messageView.scrollToBottom()
