@@ -2,7 +2,7 @@
 Copyright (c) 2007-2008 Qtrac Ltd <mark@qtrac.eu>
 Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-SPDX-License-Identifier: GPL-2.0
+SPDX-License-Identifier: GPL-2.0-only
 
 """
 
@@ -48,7 +48,7 @@ class RichTextColumnDelegate(QStyledItemDelegate):
             self.label.setTextFormat(Qt.TextFormat.RichText)
             self.document = QTextDocument()
 
-    def paint(self, painter:'QPainter', option:QStyleOptionViewItem,
+    def paint(self, painter:Optional['QPainter'], option:QStyleOptionViewItem,
         index:Union[QModelIndex,'QPersistentModelIndex']) ->None:
         """paint richtext"""
         assert isinstance(index, QModelIndex)
@@ -58,19 +58,21 @@ class RichTextColumnDelegate(QStyledItemDelegate):
             role = QPalette.ColorRole.AlternateBase if index.row() % 2 else QPalette.ColorRole.Base
         assert self.label
         self.label.setBackgroundRole(role)
-        text = index.model().data(index, Qt.ItemDataRole.DisplayRole)
-        self.label.setText(text)
+        if model := index.model():
+            text = model.data(index, Qt.ItemDataRole.DisplayRole)
+            self.label.setText(text)
         self.label.setFixedSize(option.rect.size())
-        with Painter(painter):
-            painter.translate(option.rect.topLeft())
-            self.label.render(painter)
+        if painter:
+            with Painter(painter):
+                painter.translate(option.rect.topLeft())
+                self.label.render(painter)
 
     def sizeHint(self, option:QStyleOptionViewItem, index:Union[QModelIndex,'QPersistentModelIndex']) ->QSize:
         """compute size for the final formatted richtext"""
         assert isinstance(index, QModelIndex)
-        text = index.model().data(index)
         self.document.setDefaultFont(option.font)
-        self.document.setHtml(text)
+        if model := index.model():
+            self.document.setHtml(model.data(index))
         return QSize(int(self.document.idealWidth()) + 5,
                      option.fontMetrics.height())
 
@@ -87,10 +89,12 @@ https://wiki.qt.io/Technical_FAQ#How_can_I_align_the_checkboxes_in_a_view.3F"""
     @staticmethod
     def __textMargin() ->int:
         """text margin"""
-        return QApplication.style().pixelMetric(
-            QStyle.PixelMetric.PM_FocusFrameHMargin) + 1
+        if style := QApplication.style():
+            return style.pixelMetric(
+                QStyle.PixelMetric.PM_FocusFrameHMargin) + 1
+        return 1
 
-    def paint(self, painter:'QPainter', option:QStyleOptionViewItem,
+    def paint(self, painter:Optional['QPainter'], option:QStyleOptionViewItem,
         index:Union[QModelIndex,'QPersistentModelIndex']) ->None:
         """paint right aligned checkbox"""
         assert isinstance(index, QModelIndex)
@@ -107,11 +111,15 @@ https://wiki.qt.io/Technical_FAQ#How_can_I_align_the_checkboxes_in_a_view.3F"""
                     option.rect.width() - (2 * textMargin),
                     option.rect.height()))
             viewItemOption.rect = newRect
-        QStyledItemDelegate.paint(self, painter, viewItemOption, index)
+        if painter:
+            super().paint(painter, viewItemOption, index)
 
-    def editorEvent(self, event:QEvent, model:'QAbstractItemModel',
+    def editorEvent(self, event:Optional[QEvent], model:Optional['QAbstractItemModel'],
         option:QStyleOptionViewItem, index:Union[QModelIndex,'QPersistentModelIndex']) ->bool:
         """edit right aligned checkbox"""
+        # pylint: disable=too-many-return-statements
+        if not event or not model:
+            return False
         assert isinstance(index, QModelIndex)
         flags = model.flags(index)
         # make sure that the item is checkable
